@@ -14,5 +14,5 @@ pub(super) mod huobi;
 pub(super) mod kraken;
 pub(super) mod kucoin;
 pub(super) mod mxc;
-pub(super) mod okex;
+pub(super) mod okx;
 pub(super) mod zbg;
